/**
 * EasyBeans
 * Copyright (C) 2007-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JAXWS20ResourceInjector.java 3037 2008-04-29 19:52:41Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.cxf;

import java.util.ArrayList;
import java.util.List;

import org.apache.cxf.bus.resource.ResourceManagerImpl;
import org.apache.cxf.jaxws.context.WebServiceContextResourceResolver;
import org.apache.cxf.resource.ResourceResolver;
import org.ow2.easybeans.api.bean.EasyBeansBean;
import org.ow2.easybeans.container.EmptyResourceInjector;


/**
 * Inject JAX-WS 2.0 Resource using CXF ResourceManager into the EasyBeans EJB instance.
 * Add the resource resolver for the WebServicesContext resource.
 * @author Guillaume Sauthier
 * @author Florent Benoit
 */
public class JAXWS20ResourceInjector extends EmptyResourceInjector {

    /**
     * Called <b>after</b> EasyBeans resolution and injection of dependencies.
     * @param bean the Bean instance.
     */
    @Override
    public void postEasyBeansInject(final EasyBeansBean bean) {
        // no-op
    }

    /**
     * Called <b>before</b> EasyBeans resolution and injection of dependencies.
     * @param bean the Bean instance.
     */
    @Override
    public void preEasyBeansInject(final EasyBeansBean bean) {
        List<ResourceResolver> resourceResolvers = new ArrayList<ResourceResolver>();
        resourceResolvers.add(new WebServiceContextResourceResolver());
        ResourceManagerImpl resourceManagerImpl = new ResourceManagerImpl(resourceResolvers);

        // Inject the resource in the Bean instance
        CXFResourceInjector cri = new CXFResourceInjector(resourceManagerImpl);
        cri.inject(bean);
    }

}
