/**
 * EasyBeans
 * Copyright (C) 2007-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EasyBeansCXFServlet.java 2546 2008-02-29 13:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.cxf.http;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;

/**
 * Easybeans specialized Servlet. It only gets the Singleton TransportFactory
 * and use it to map URL to Endpoints.
 * @author Guillaume Sauthier
 * @author Florent Benoit
 */
public class EasyBeansCXFServlet extends HttpServlet {

    /**
     * Serial Version UID.
     */
    private static final long serialVersionUID = 2241539363010941679L;

    /**
     * Called by the server (via the service method) to allow a servlet to
     * handle a POST request.
     * @param request an HttpServletRequest object that contains the request the
     *        client has made of the servlet
     * @param response an HttpServletResponse object that contains the response
     *        the servlet sends to the client
     * @throws ServletException if the request for the POST could not be handled
     */
    @Override
    protected void doPost(final HttpServletRequest request,
                          final HttpServletResponse response) throws ServletException {
        invokeDestination(request, response);
    }

    /**
     * Called by the server (via the service method) to allow a servlet to
     * handle a GET request.
     * @param request an HttpServletRequest object that contains the request the
     *        client has made of the servlet
     * @param response an HttpServletResponse object that contains the response
     *        the servlet sends to the client
     * @throws ServletException if the request for the GET could not be handled
     */
    @Override
    protected void doGet(final HttpServletRequest request,
                         final HttpServletResponse response) throws ServletException {
        invokeDestination(request, response);
    }

    /**
     * Invoke the Destination object by analyzing the given request.
     * @param request the given request
     * @param response an HttpServletResponse object that contains the response
     *        the servlet sends to the client
     * @throws ServletException if the invocation fails
     */
    protected void invokeDestination(final HttpServletRequest request,
                                     final HttpServletResponse response)
            throws ServletException {
        URLMapper mapper = URLMapper.getInstance();
        if (mapper == null || mapper.getServantMap().isEmpty()) {
            throw new ServletException("Unknown servlet mapping (no servants) " + request.getPathInfo());
        }

        EasyBeansDestination dest = mapper.get(request.getPathInfo());

        // dest may be null (and that's OK)

        Bus old = BusFactory.getThreadDefaultBus();
        try {
            if (dest != null) {
                BusFactory.setThreadDefaultBus(dest.getBus());
            }
            ServletHelper.invoke(request, response, dest, getServletContext());
        } finally {
            BusFactory.setThreadDefaultBus(old);
        }

    }
}
