/**
 * EasyBeans
 * Copyright (C) 2006-2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: URLMapper.java 2546 2008-02-29 13:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.cxf.http;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Stores path to ServletServerTransport mapping.
 * @author sauthieg
 */
final class URLMapper {

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(URLMapper.class);

    /**
     * Unique instance.
     */
    private static URLMapper instance = null;

    /**
     * servant Map.
     */
    private Map<String, EasyBeansDestination> servantMap = null;

    /**
     * Private Constructor (Singleton).
     */
    private URLMapper() {
        this.servantMap = new ConcurrentHashMap<String, EasyBeansDestination>();
    }

    /**
     * @param pathInfo endpoint key.
     * @return Returns the <code>ServletServerTransport</code> mapped instance.
     */
    public EasyBeansDestination get(final String pathInfo) {
        if (pathInfo == null) {
            return null;
        }
        logger.debug("get : {0}", pathInfo);
        return this.servantMap.get(pathInfo);
    }

    /**
     * Add a new servant.
     * @param url mapped URL
     * @param servant mapped transport.
     */
    public void addServant(final String path,
                           final EasyBeansDestination servant) {
        logger.debug("put : {0}", path);
        this.servantMap.put(path, servant);
    }

    /**
     * Remove a servant.
     * @param url mapped URL
     * @param servant mapped transport.
     */
    public void removeServant(final String path,
                              final EasyBeansDestination servant) {
        this.servantMap.remove(path);
    }

    /**
     * @return Returns the unique {@link URLMapper} instance.
     */
    public static URLMapper getInstance() {
        if (instance == null) {
            instance = new URLMapper();
        }
        return instance;
    }

    /**
     * @return the map of all servants managed by this mapper.
     */
    public Map<String, EasyBeansDestination> getServantMap() {
        return this.servantMap;
    }

}
